@@ -137,7 +137,7 @@ class ImportPlugin(object):
         main_iteration = Gtk.main_iteration
 
         # get some values from DB to avoid queries in the loop
-        statement = select([db.Movie.number, db.Movie.title, db.Movie.o_title])
+        statement = select(db.Movie.number, db.Movie.title, db.Movie.o_title)
         data = session.execute(statement).fetchall()
         numbers = set(i[0] for i in data)
         titles = set(i[1].lower() for i in data if i[1])
@@ -241,8 +241,7 @@ class ImportPlugin(object):
                             # selected validate_details will remove it
                             details['number'] = number
                             # insert the movie in the database
-                            movie = db.tables.movies.insert(
-                                bind=self.db.session.bind).execute(details)
+                            result = session.execute(db.tables.movies.insert(), details)
                             self.imported += 1
                             # optional: adding tags
                             if tags:
@@ -255,11 +254,13 @@ class ImportPlugin(object):
                                             tag_id = self.tagmap[tag.lower()]
                                         else:
                                             tag_id = int(tag)
-                                        db.tables.movie_tag.insert(
-                                            bind=self.db.session.bind).execute({
-                                            'movie_id': movie.lastrowid,
-                                            'tag_id': tag_id
-                                            })
+                                        session.execute(
+                                            db.tables.movie_tag.insert(),
+                                            {
+                                                'movie_id': result.lastrowid,
+                                                'tag_id': tag_id,
+                                            },
+                                        )
                                     except Exception as ex:
                                         log.error(f"[E013]Caught too broad "
                                                   f"try-exception "
